@@ -32,6 +32,13 @@ class Membership(BaseModel):
     _validate_name = validator("name", allow_reuse=True)(validate_str_no_newline)
     _validate_role = validator("role", allow_reuse=True)(validate_str_no_newline)
 
+    @validator("name")
+    def not_blank(cls, val: str) -> str:
+        val = val.strip()
+        if not val:
+            raise ValueError("empty name")
+        return val
+
 
 class ScrapeCommittee(BaseModel):
     name: str
@@ -78,6 +85,12 @@ class Committee(ScrapeCommittee):
     _validate_id = validator("id", allow_reuse=True)(validate_ocd_organization)
     _validate_parent = validator("parent", allow_reuse=True)(validate_ocd_organization)
 
+    @root_validator
+    def validate_has_members(cls, data: dict[str, typing.Any]) -> dict[str, typing.Any]:
+        if not len(data.get("members", [])):  # type: ignore
+            raise ValueError("committees must have members")
+        return data
+
     def to_dict(self) -> dict[str, typing.Any]:
         # hack to always have id on top & always include classification
         return {
